@@ -72,7 +72,7 @@ K_EXPORT_COMPONENT_FACTORY( kcm_gtk, KcmGtkFactory("gtk"))*/
 
 extern "C"
 {
-	KDE_EXPORT TDECModule *create_kcmgtk( TQWidget * parent, const char * name )
+	TDE_EXPORT TDECModule *create_kcmgtk( TQWidget * parent, const char * name )
 	{
 		TDEGlobal::locale()->insertCatalogue( "gtk-qt-engine" );
 		return new KcmGtk( parent, "kcmgtk" );
